aboutsummaryrefslogtreecommitdiffstats
path: root/fs/kernfs/mount.c
diff options
context:
space:
mode:
authorTejun Heo <tj@kernel.org>2013-12-11 14:11:55 -0500
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2013-12-11 17:39:20 -0800
commitc525aaddc366df23eb095d58a2bdf11cce62a98b (patch)
tree4f1e5e85e619e46daef45537bd5926925587b463 /fs/kernfs/mount.c
parentkernfs: drop s_ prefix from kernfs_node members (diff)
downloadlinux-dev-c525aaddc366df23eb095d58a2bdf11cce62a98b.tar.xz
linux-dev-c525aaddc366df23eb095d58a2bdf11cce62a98b.zip
kernfs: s/sysfs/kernfs/ in various data structures
kernfs has just been separated out from sysfs and we're already in full conflict mode. Nothing can make the situation any worse. Let's take the chance to name things properly. This patch performs the following renames. * s/sysfs_open_dirent/kernfs_open_node/ * s/sysfs_open_file/kernfs_open_file/ * s/sysfs_inode_attrs/kernfs_iattrs/ * s/sysfs_addrm_cxt/kernfs_addrm_cxt/ * s/sysfs_super_info/kernfs_super_info/ * s/sysfs_info()/kernfs_info()/ * s/sysfs_open_dirent_lock/kernfs_open_node_lock/ * s/sysfs_open_file_mutex/kernfs_open_file_mutex/ * s/sysfs_of()/kernfs_of()/ This patch is strictly rename only and doesn't introduce any functional difference. Signed-off-by: Tejun Heo <tj@kernel.org> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'fs/kernfs/mount.c')
-rw-r--r--fs/kernfs/mount.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/fs/kernfs/mount.c b/fs/kernfs/mount.c
index 9dbbf37b1af9..e0796dcb6065 100644
--- a/fs/kernfs/mount.c
+++ b/fs/kernfs/mount.c
@@ -27,7 +27,7 @@ static const struct super_operations sysfs_ops = {
static int sysfs_fill_super(struct super_block *sb)
{
- struct sysfs_super_info *info = sysfs_info(sb);
+ struct kernfs_super_info *info = kernfs_info(sb);
struct inode *inode;
struct dentry *root;
@@ -61,8 +61,8 @@ static int sysfs_fill_super(struct super_block *sb)
static int sysfs_test_super(struct super_block *sb, void *data)
{
- struct sysfs_super_info *sb_info = sysfs_info(sb);
- struct sysfs_super_info *info = data;
+ struct kernfs_super_info *sb_info = kernfs_info(sb);
+ struct kernfs_super_info *info = data;
return sb_info->root == info->root && sb_info->ns == info->ns;
}
@@ -84,7 +84,7 @@ static int sysfs_set_super(struct super_block *sb, void *data)
*/
const void *kernfs_super_ns(struct super_block *sb)
{
- struct sysfs_super_info *info = sysfs_info(sb);
+ struct kernfs_super_info *info = kernfs_info(sb);
return info->ns;
}
@@ -107,7 +107,7 @@ struct dentry *kernfs_mount_ns(struct file_system_type *fs_type, int flags,
struct kernfs_root *root, const void *ns)
{
struct super_block *sb;
- struct sysfs_super_info *info;
+ struct kernfs_super_info *info;
int error;
info = kzalloc(sizeof(*info), GFP_KERNEL);
@@ -144,12 +144,12 @@ struct dentry *kernfs_mount_ns(struct file_system_type *fs_type, int flags,
*/
void kernfs_kill_sb(struct super_block *sb)
{
- struct sysfs_super_info *info = sysfs_info(sb);
+ struct kernfs_super_info *info = kernfs_info(sb);
struct kernfs_node *root_kn = sb->s_root->d_fsdata;
/*
* Remove the superblock from fs_supers/s_instances
* so we can't find it, before freeing sysfs_super_info.
*/
kill_anon_super(sb);
kfree(info);
@@ -144,12 +144,12 @@ struct dentry *kernfs_mount_ns(struct file_system_type *fs_type, int flags,
/*
* Remove the superblock from fs_supers/s_instances
- * so we can't find it, before freeing sysfs_super_info.
+ * so we can't find it, before freeing kernfs_super_info.
*/
kill_anon_super(sb);